@@ -1,24 +1,9 @@
 /*
-  kwikdisk.cpp - KDiskFree
+    SPDX-FileCopyrightText: 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
+    SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
 
-  Copyright (C) 1999 by Michael Kropfberger <michael.kropfberger@gmx.net>
-                2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-  */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 //
 // 1999-12-03 Espen Sand
@@ -52,9 +37,6 @@
 
 #include <unistd.h>
 
-static const char description[] =
-    I18N_NOOP("KDE Free disk space utility");
-
 /*****************************************************************************/
 
 KwikDisk::KwikDisk()
@@ -253,10 +235,10 @@ void KwikDisk::toggleMount(QAction * action)
     {
         KMessageBox::error(nullptr, disk->lastSysError());
     }
-    else if( (m_options.openFileManager() == true) && (disk->mounted() == true ) )
+    else if( m_options.openFileManager() && ( disk->mounted() ) )
     {
         qCDebug(KDF) << "opening filemanager";
-        if( m_options.fileManager().isEmpty() == false )
+        if( !m_options.fileManager().isEmpty() )
         {
             QString cmd = m_options.fileManager();
             int pos = cmd.indexOf(QLatin1String( "%m" ));
@@ -268,7 +250,9 @@ void KwikDisk::toggleMount(QAction * action)
             {
                 cmd += QLatin1Char( ' ' ) + KShell::quoteArg(disk->mountPoint());
             }
-            QProcess::startDetached(cmd, QStringList());
+            QStringList argList = cmd.split(QLatin1Char( ' ' ), Qt::SkipEmptyParts);
+            cmd = argList.takeFirst();
+            QProcess::startDetached(cmd, argList);
         }
     }
     m_dirty = true;
@@ -324,7 +308,7 @@ int main(int argc, char **argv)
     KAboutData aboutData(QStringLiteral("kwikdisk"),
                      i18n("KwikDisk"),
                      QStringLiteral(KDF_VERSION_STRING),
-                     i18n(description),
+                     i18n("KDE Free disk space utility"),
                      KAboutLicense::GPL,
                      i18n("(C) 2004 Stanislav Karchebny"),
                      QString(),
